/**
 * Scripts within the customizer controls window.
 *
 * Contextually shows the color hue control and informs the preview
 * when users open or close the front page sections section.
 */

(function( $, api ) {
    wp.customize.bind('ready', function() {
    	// Show message on change.
        var lawman_pro_settings = ['lawman_pro_slider_num', 'lawman_pro_services_num', 'lawman_pro_projects_num', 'lawman_pro_testimonial_num', 'lawman_pro_blog_section_num', 'lawman_pro_reset_settings', 'lawman_pro_testimonial_num', 'lawman_pro_partner_num'];
        _.each( lawman_pro_settings, function( lawman_pro_setting ) {
            wp.customize( lawman_pro_setting, function( setting ) {
                var lawmanNotice = function( value ) {
                    var name = 'needs_refresh';
                    if ( value && lawman_pro_setting == 'lawman_pro_reset_settings' ) {
                        setting.notifications.add( 'needs_refresh', new wp.customize.Notification(
                            name,
                            {
                                type: 'warning',
                                message: localized_data.reset_msg,
                            }
                        ) );
                    } else if( value ){
                        setting.notifications.add( 'reset_name', new wp.customize.Notification(
                            name,
                            {
                                type: 'info',
                                message: localized_data.refresh_msg,
                            }
                        ) );
                    } else {
                        setting.notifications.remove( name );
                    }
                };

                setting.bind( lawmanNotice );
            });
        });

        /* === Radio Image Control === */
        api.controlConstructor['radio-color'] = api.Control.extend( {
            ready: function() {
                var control = this;

                $( 'input:radio', control.container ).change(
                    function() {
                        control.setting.set( $( this ).val() );
                    }
                );
            }
        } );

        // Sortable sections
        jQuery( "body" ).on( 'hover', '.lawman-drag-handle', function() {
            jQuery( 'ul.lawman-sortable-list' ).sortable({
                handle: '.lawman-drag-handle',
                axis: 'y',
                update: function( e, ui ){
                    jQuery('input.lawman-sortable-input').trigger( 'change' );
                }
            });
        });

        /* On changing the value. */
        jQuery( "body" ).on( 'change', 'input.lawman-sortable-input', function() {
            /* Get the value, and convert to string. */
            this_checkboxes_values = jQuery( this ).parents( 'ul.lawman-sortable-list' ).find( 'input.lawman-sortable-input' ).map( function() {
                return this.value;
            }).get().join( ',' );

            /* Add the value to hidden input. */
            jQuery( this ).parents( 'ul.lawman-sortable-list' ).find( 'input.lawman-sortable-value' ).val( this_checkboxes_values ).trigger( 'change' );

        });

        // Deep linking for counter section to about section.
        jQuery('.lawman-edit').click(function(e) {
            e.preventDefault();
            var jump_to = jQuery(this).attr( 'data-jump' );
            wp.customize.section( jump_to ).focus()
        });

    });
})( jQuery, wp.customize );

jQuery(document).ready(function($) {

    // topbar
    $( "#customize-control-lawman_pro_topbar_menu_bg_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_topbar_item_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_topbar_item_hover_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_topbar_icon_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_topbar_setting span" ).first().click(function() {
        $( "#customize-control-lawman_pro_topbar" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_social_menu" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_location" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_contact" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_menu_bg_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_item_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_icon_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_item_hover_color" ).css("display" , "none");
    });
    $( "#customize-control-lawman_pro_topbar_setting span" ).last().click(function() {
        $( "#customize-control-lawman_pro_topbar" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_social_menu" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_location" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_contact" ).css("display" , "none");
        $( "#customize-control-lawman_pro_topbar_menu_bg_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_item_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_icon_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_topbar_item_hover_color" ).css("display" , "block");
    });


    // header
    $( "#customize-control-lawman_pro_header_nav_padding" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_top_banner" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_title_font_size" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_nav_top_border" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_nav_font_size" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_nav_item_margin" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_section_menu_bg_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_section_top_border_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_section_nav_item_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_section_nav_item_hover_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_section_nav_bottom_border_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_background" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_background_image" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_background_color" ).css("display" , "none");
    $( "#customize-control-lawman_pro_header_nav_botton_border" ).css("display" , "none");

    $( "#customize-control-lawman_pro_header_setting span" ).first().click(function() { 
        $( "#customize-control-lawman_pro_header_style" ).css("display" , "block");
        $( "#customize-control-lawman_pro_make_menu_sticky" ).css("display" , "block");
        $( "#customize-control-lawman_pro_make_trasparent_menu" ).css("display" , "block");

        $( "#customize-control-lawman_pro_header_nav_padding" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_top_banner" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_title_font_size" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_nav_top_border" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_nav_font_size" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_nav_item_margin" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_section_menu_bg_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_section_top_border_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_section_nav_item_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_section_nav_item_hover_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_section_nav_bottom_border_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_background" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_background_image" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_background_color" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_nav_botton_border" ).css("display" , "none");
    });

    $( "#customize-control-lawman_pro_header_setting span" ).last().click(function() { 
        $( "#customize-control-lawman_pro_header_style" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_display" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_ads_image" ).css("display" , "none");
        $( "#customize-control-lawman_pro_header_ads_image_url" ).css("display" , "none");
        $( "#customize-control-lawman_pro_make_menu_sticky" ).css("display" , "none");
        $( "#customize-control-lawman_pro_make_trasparent_menu" ).css("display" , "none");

        $( "#customize-control-lawman_pro_header_nav_padding" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_top_banner" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_title_font_size" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_nav_top_border" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_nav_font_size" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_nav_item_margin" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_section_menu_bg_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_nav_botton_border" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_section_top_border_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_section_nav_item_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_section_nav_item_hover_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_section_nav_bottom_border_color" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_background" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_background_image" ).css("display" , "block");
        $( "#customize-control-lawman_pro_header_background_color" ).css("display" , "block");
    });


});
