<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 *
 * client section
 */

$wp_customize->add_section(
	'lawman_pro_client',
	array(
		'title' => esc_html__( 'Client', 'lawman-pro' ),
		'panel' => 'lawman_pro_home_panel',
	)
);

// client enable settings
$wp_customize->add_setting(
	'lawman_pro_client',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
		'default' => 'disable'
	)
);

$wp_customize->add_control(
	'lawman_pro_client',
	array(
		'section'		=> 'lawman_pro_client',
		'label'			=> esc_html__( 'Content type:', 'lawman-pro' ),
		'description'	=> esc_html__( 'Choose where you want to render the content from.', 'lawman-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'lawman-pro' ),
				'post' => esc_html__( 'Post', 'lawman-pro' ),
				'page' => esc_html__( 'Page', 'lawman-pro' ),
				'custom' => esc_html__( 'Custom', 'lawman-pro' ),
				'cat' => esc_html__( 'Category', 'lawman-pro' ),
		 	)
	)
);

$wp_customize->add_setting(
	'lawman_pro_client_num',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_number_range',
		'default' => 5,
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_client_num',
	array(
		'section'		=> 'lawman_pro_client',
		'label'			=> esc_html__( 'Number of Posts:', 'lawman-pro' ),
		'description'	=> esc_html__( 'Min: 1 | Max: 5', 'lawman-pro' ),
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 1, 'max' => 5 ),
	)
);


$client_num = get_theme_mod( 'lawman_pro_client_num', 5 );
for ($i=1; $i <= $client_num ; $i++) { 
	// client post setting
	$wp_customize->add_setting(
		'lawman_pro_client_post_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_client_post_'.$i,
		array(
			'section'		=> 'lawman_pro_client',
			'label'			=> esc_html__( 'Post ', 'lawman-pro' ).$i,
			'active_callback' => 'lawman_pro_if_client_post',
			'type'			=> 'select',
			'choices'		=> lawman_pro_get_post_choices(),
		)
	);

	
	$wp_customize->add_setting( 
		'lawman_pro_client_image_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_image',
		) 
	);

	$wp_customize->add_control( 
		new WP_Customize_Image_Control( $wp_customize, 'lawman_pro_client_image_'.$i,
		array(
			'label'       		=> esc_html__( 'Client Image', 'lawman-pro' ),
			'section'     		=> 'lawman_pro_client',
			'active_callback'	=> 'lawman_pro_if_client_custom',
		)
	) );

	$wp_customize->add_setting(
		'lawman_pro_client_image_url_'.$i,
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	
	$wp_customize->add_control(
		'lawman_pro_client_image_url_'.$i,
		array(
			'section'		=> 'lawman_pro_client',
			'label'			=> esc_html__( 'Image Url:', 'lawman-pro' ),
			'type'			=> 'url',
			'active_callback'	=> 'lawman_pro_if_client_custom',
		)
	);

	// client page setting
	$wp_customize->add_setting(
		'lawman_pro_client_page_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'lawman_pro_client_page_'.$i,
		array(
			'section'		=> 'lawman_pro_client',
			'label'			=> esc_html__( 'Page ', 'lawman-pro' ).$i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'lawman_pro_if_client_page'
		)
	);
}

// client category setting
$wp_customize->add_setting(
	'lawman_pro_client_cat',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'lawman_pro_client_cat',
	array(
		'section'		=> 'lawman_pro_client',
		'label'			=> esc_html__( 'Category:', 'lawman-pro' ),
		'active_callback' => 'lawman_pro_if_client_cat',
		'type'			=> 'select',
		'choices'		=> lawman_pro_get_post_cat_choices(),
	)
);
