<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 */

/**
 * Get all the default values of the theme mods.
 */
function lawman_pro_get_default_mods() {
	$lawman_pro_default_mods = array(
		// Footer copyright
		'lawman_pro_copyright_txt' => esc_html__( '&copy; [the-year] [site-link]. All Right Reserved ', 'lawman-pro' ),
		'lawman_pro_power_by_txt'	=> sprintf( esc_html__( 'Design By %1$s ', 'lawman-pro' ), '<a href="' . esc_url( 'http://moralthemes.com/' ) . '">Moral Themes</a>' ),
	);

	return apply_filters( 'lawman_pro_default_mods', $lawman_pro_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function lawman_pro_customize_register( $wp_customize ) {

	// Custom Controller
	require get_parent_theme_file_path( '/inc/customizer/custom-controller.php' );

	$default = lawman_pro_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'lawman_pro_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'lawman_pro_customize_partial_blogdescription',
		) );
	}

	//header text
	$wp_customize->add_setting(
	'lawman_pro_header_text',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'View Full Stories', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
	);

	$wp_customize->add_control(
		'lawman_pro_header_text',
		array(
			'section'		=> 'header_media',
			'label'			=> esc_html__( 'Header Text:', 'lawman-pro' ),
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'lawman_pro_header_text', 
		array(
	        'selector'            => '#about-us .read-more a',
			'render_callback'     => 'lawman_pro_about_partial_btn_title',
		) 
	);
	//Color Panel

	// Header tagline color setting
	$wp_customize->add_setting(	
		'lawman_pro_header_tagline',
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_hex_color',
			'default' => '#929292',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'lawman_pro_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'lawman-pro' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'lawman_pro_theme_color_scheme',
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_select',
			'default' => 'lite-version',
		)
	);

	$wp_customize->add_control( 'lawman_pro_theme_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio',
			'label'			=> esc_html__( 'Theme color scheme:', 'lawman-pro' ),
			'choices'			=> array( 
				'lite-version' => esc_html__( 'Lite', 'lawman-pro' ), 
				'dark-version' => esc_html__( 'Dark', 'lawman-pro' ), 
			),
		)
	);

	// Color scheme setting
	$wp_customize->add_setting(	
		'lawman_pro_color_scheme',
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_select',
			'default'	=> 'default',
		)
	);

	$wp_customize->add_control( 
		new lawman_pro_Customize_Control_Radio_Color( 
		$wp_customize,
		'lawman_pro_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio-color',
			'label'			=> esc_html__( 'Color scheme:', 'lawman-pro' ),
			'choices'		=> array( 
				'default' => array( 
					'color' => '#000'
				),
				'red' => array( 
					'color' => '#fb3c3c'
				),
				'green' => array( 
					'color' => '#0cc652'
				),
				'yellow' => array( 
					'color' => '#f5d246'
				),
				'custom' => array( 
					'color' => '#0563D8'
				),
			),
		)
	)
	);

	// Custom color scheme scheme setting
	$wp_customize->add_setting(	
		'lawman_pro_custom_color_scheme',
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_hex_color',
			'default' => '#e83a3c',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'lawman_pro_custom_color_scheme',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Custom color:', 'lawman-pro' ),
				'active_callback' => 'lawman_pro_if_custom_color_scheme',
			)
		)
	);

	// Header text display setting
	$wp_customize->add_setting(	
		'lawman_pro_header_text_display',
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'lawman-pro' ),
		)
	);

	// Your latest posts title setting
	$wp_customize->add_setting(	
		'lawman_pro_your_latest_posts_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Blogs', 'lawman-pro' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_your_latest_posts_title',
		array(
			'section'		=> 'static_front_page',
			'label'			=> esc_html__( 'Title:', 'lawman-pro' ),
			'active_callback' => 'lawman_pro_is_latest_posts'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'lawman_pro_your_latest_posts_title', 
		array(
	        'selector'            => '.home.blog #page-header .page-title',
			'render_callback'     => 'lawman_pro_your_latest_posts_partial_title',
    	) 
    );

	/**
	 * 
	 * Front Section
	 * 
	 */ 

	// Home sections panel
	$wp_customize->add_panel(
		'lawman_pro_home_panel',
		array(
			'title' => esc_html__( 'Homepage Options', 'lawman-pro' ),
			'priority' => 105
		)
	);

	//home-layout
    require get_parent_theme_file_path( '/inc/customizer/home-layout.php' );

    //top-bar
    require get_parent_theme_file_path( '/inc/customizer/top-bar.php' );


    if ( get_theme_mod('lawman_pro_homepage_layout', 'first-design' ) == 'first-design' || get_theme_mod('lawman_pro_homepage_layout', 'first-design' ) == 'fourth-design' ) {	
			
		//slider
		require get_parent_theme_file_path( '/inc/customizer/slider.php' );

		//main services
		require get_parent_theme_file_path( '/inc/customizer/main-service.php' );
				
		//about
		require get_parent_theme_file_path( '/inc/customizer/about-us.php' );

		//service
		require get_parent_theme_file_path( '/inc/customizer/service.php' );

		//portfolio
		require get_parent_theme_file_path( '/inc/customizer/portfolio.php' );

		//cta
		require get_parent_theme_file_path( '/inc/customizer/cta.php' );
		
		//testinomial
		require get_parent_theme_file_path( '/inc/customizer/testinomial.php' );

		//team
		require get_parent_theme_file_path( '/inc/customizer/team.php' );
		
		//client
		require get_parent_theme_file_path( '/inc/customizer/client.php' );
		
		//related
		require get_parent_theme_file_path( '/inc/customizer/related.php' );

		//call us
		require get_parent_theme_file_path( '/inc/customizer/callus.php' );


    }

    if ( get_theme_mod('lawman_pro_homepage_layout', 'first-design' ) == 'second-design' ) {	

			
		//slider
		require get_parent_theme_file_path( '/inc/customizer/slider.php' );

		//about
		require get_parent_theme_file_path( '/inc/customizer/about.php' );

		//main services
		require get_parent_theme_file_path( '/inc/customizer/main-service.php' );

		//portfolio
		require get_parent_theme_file_path( '/inc/customizer/portfolio.php' );
		
		//testinomial
		require get_parent_theme_file_path( '/inc/customizer/testinomial.php' );
		
		//related
		require get_parent_theme_file_path( '/inc/customizer/client.php' );
		
		//cta
		require get_parent_theme_file_path( '/inc/customizer/cta.php' );

		//service
		require get_parent_theme_file_path( '/inc/customizer/service.php' );
		
		//related
		require get_parent_theme_file_path( '/inc/customizer/related.php' );
		
		//call us
		require get_parent_theme_file_path( '/inc/customizer/callus.php' );
		

    }

    if ( get_theme_mod('lawman_pro_homepage_layout', 'first-design' ) == 'third-design' ) {	

		
		//slider
		require get_parent_theme_file_path( '/inc/customizer/slider.php' );
		
		//about
		require get_parent_theme_file_path( '/inc/customizer/featured.php' );
		
		//popular
		require get_parent_theme_file_path( '/inc/customizer/popular.php' );
		
		//latest
		require get_parent_theme_file_path( '/inc/customizer/latest.php' );

    }

	// Theme Options
	require get_parent_theme_file_path( '/inc/customizer/theme-option.php' );
}
add_action( 'customize_register', 'lawman_pro_customize_register' );


// Sanitize Callback
require get_parent_theme_file_path( '/inc/customizer/sanitize-callback.php' );

// active Callback
require get_parent_theme_file_path( '/inc/customizer/active-callback.php' );

// Partial Refresh
require get_parent_theme_file_path( '/inc/customizer/partial-refresh.php' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function lawman_pro_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function lawman_pro_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function lawman_pro_customize_preview_js() {
	wp_enqueue_script( 'lawman-pro-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'lawman_pro_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function lawman_pro_customize_control_js() {


	wp_enqueue_style( 'lawman-pro-customize-style', get_theme_file_uri( '/assets/css/customize-controls.css' ), array(), '20151215' );

	wp_enqueue_script( 'lawman-pro-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'lawman-pro' ),
		'reset_msg' => esc_html__( 'Warning!!! This will reset all the settings. Refresh the page after Save and Publish to reset all.', 'lawman-pro' ),
	);

	wp_localize_script( 'lawman-pro-customize-control', 'localized_data', $localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'lawman_pro_customize_control_js' );
