<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 *
 * portfolio section
 */

$wp_customize->add_section(
	'lawman_pro_portfolio',
	array(
		'title' => esc_html__( 'Portfolio', 'lawman-pro' ),
		'panel' => 'lawman_pro_home_panel',
	)
);

// portfolio enable settings
$wp_customize->add_setting(
	'lawman_pro_portfolio',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
		'default' => 'cat'
	)
);

$wp_customize->add_control(
	'lawman_pro_portfolio',
	array(
		'section'		=> 'lawman_pro_portfolio',
		'label'			=> esc_html__( 'Content type:', 'lawman-pro' ),
		'description'	=> esc_html__( 'Choose where you want to render the content from.', 'lawman-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'lawman-pro' ),
				'cat' => esc_html__( 'Category', 'lawman-pro' ),
		 	)
	)
);


$wp_customize->add_setting(
	'lawman_pro_portfolio_num',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_number_range',
		'default' => 4,
		'transport'	=> 'refresh',
	)
);

$wp_customize->add_control(
	'lawman_pro_portfolio_num',
	array(
		'section'		=> 'lawman_pro_portfolio',
		'label'			=> esc_html__( 'Number of Posts:', 'lawman-pro' ),
		'description'	=> esc_html__( 'Min: 4 | Max: 8', 'lawman-pro' ),
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 4, 'max' => 8 ),
	)
);


$wp_customize->add_setting(
	'lawman_pro_portfolio_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'We fight for your right', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_portfolio_title',
	array(
		'section'		=> 'lawman_pro_portfolio',
		'label'			=> esc_html__( 'Title:', 'lawman-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_portfolio_title', 
	array(
        'selector'            => '#portfolio div.section-header h2',
		'render_callback'     => 'lawman_pro_portfolio_partial_title',
	) 
);

$wp_customize->add_setting(
	'lawman_pro_portfolio_sub_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'Our Portfolio', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_portfolio_sub_title',
	array(
		'section'		=> 'lawman_pro_portfolio',
		'label'			=> esc_html__( 'Sub Title:', 'lawman-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_portfolio_sub_title', 
	array(
        'selector'            => '#portfolio div.section-header p',
		'render_callback'     => 'lawman_pro_portfolio_partial_sub_title',
	) 
);


for ($i=1; $i <= 4 ; $i++) { 
	// portfolio category setting
	$wp_customize->add_setting(
		'lawman_pro_portfolio_cat_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_portfolio_cat_'.$i,
		array(
			'section'		=> 'lawman_pro_portfolio',
			'label'			=> esc_html__( 'Category:', 'lawman-pro' ),
			'active_callback' => 'lawman_pro_if_portfolio_cat',
			'type'			=> 'select',
			'choices'		=> lawman_pro_get_post_cat_choices(),
		)
	);
}


$wp_customize->add_setting(
	'lawman_pro_portfolio_btn_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'View all Projects', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_portfolio_btn_title',
	array(
		'section'			=> 'lawman_pro_portfolio',
		'label'				=> esc_html__( 'Btn Title:', 'lawman-pro' ),
		'active_callback'	=> function(){
			return get_theme_mod( 'lawman_pro_homepage_layout' ) == 'second-design';
		}
		
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_portfolio_btn_title', 
	array(
		'selector'            => '#portfolio .read-more a',
		'render_callback'     => 'lawman_pro_portfolio_partial_btn_title',
	) 
);

$wp_customize->add_setting(
	'lawman_pro_portfolio_btn_url',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'lawman_pro_portfolio_btn_url',
	array(
		'section'		=> 'lawman_pro_portfolio',
		'label'			=> esc_html__( 'Btn Url:', 'lawman-pro' ),
		'active_callback'	=> function(){
			return get_theme_mod( 'lawman_pro_homepage_layout' ) == 'second-design';
		}
	)
);
